/*
**  SendView.m
**
**  Copyright (c) 2001, 2002, 2003
**
**  Author: Ludovic Marcotte <ludovic@Sophos.ca>
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include "SendView.h"

#include "Constants.h"
#include "LabelWidget.h"

//
//
//
@implementation SendView

- (void) dealloc
{
  NSDebugLog(@"SendView: -dealloc");
  
  RELEASE(sendTransportMethodPopUpButton);
  
  RELEASE(sendMailerField);

  RELEASE(sendSMTPHostField);
  RELEASE(sendSMTPPortField);

  RELEASE(sendSMTPUsernameField);
  RELEASE(sendSMTPPasswordSecureField);
  RELEASE(sendRememberPassword);
  RELEASE(sendUseSecureConnection);

  RELEASE(sendAuthenticateUsingButton);
  RELEASE(sendSupportedMechanismsButton);
  RELEASE(sendSupportedMechanismsPopUp);

  [super dealloc];
}


//
//
//
- (id) initWithParent: (id) theParent
{
  self = [super init];

  parent = theParent;

  return self;
}


//
//
//
- (void) layoutView
{
  LabelWidget *label;
  NSBox *box;

  [self setFrame: NSMakeRect(0,0,400,360)];
  [self setAutoresizingMask: NSViewWidthSizable|NSViewHeightSizable];
  
  label = [LabelWidget labelWidgetWithFrame: NSMakeRect(10,300,380,30)
		       label: _(@"Usually in this panel, you would want to add the information related\nto your outgoing mail server (most of the time, SMTP).")];
  [self addSubview: label];

  label = [LabelWidget labelWidgetWithFrame: NSMakeRect(10,265,110,TextFieldHeight)
		       label: _(@"Transport method:")];
  [self addSubview: label];
  
  sendTransportMethodPopUpButton = [[NSPopUpButton alloc] initWithFrame: NSMakeRect(130,263,125,ButtonHeight)];
  [sendTransportMethodPopUpButton setAutoenablesItems: NO];
  [sendTransportMethodPopUpButton addItemWithTitle: _(@"Mailer")];
  [sendTransportMethodPopUpButton addItemWithTitle: _(@"SMTP")];
  [sendTransportMethodPopUpButton setTarget: parent];
  [sendTransportMethodPopUpButton setAction: @selector(sendTransportMethodHasChanged:)];
  [self addSubview: sendTransportMethodPopUpButton];
  
  //
  // MAILER
  //
  label = [LabelWidget labelWidgetWithFrame: NSMakeRect(10,225,60,TextFieldHeight)
		       label: _(@"Mailer:")
		       alignment: NSRightTextAlignment];
  [self addSubview: label];
  
  label = [LabelWidget labelWidgetWithFrame: NSMakeRect(10,205,200,TextFieldHeight)
		       label: _(@"(Ex: /usr/sbin/sendmail -t)")
		       alignment: NSLeftTextAlignment];
  [label setFont: [NSFont systemFontOfSize: 10]];
  [self addSubview: label];

  sendMailerField = [[NSTextField alloc] initWithFrame: NSMakeRect(75,225,300,TextFieldHeight)];
  [self addSubview: sendMailerField];


  //
  // Our separator
  //
  box = [[NSBox alloc] initWithFrame: NSMakeRect(15,200,370,1)];
  [box setTitlePosition: NSNoTitle];
  [box setBorderType: NSLineBorder];
  [self addSubview: box];
  RELEASE(box);


  //
  // SMTP
  //
  label = [LabelWidget labelWidgetWithFrame: NSMakeRect(10,165,60,TextFieldHeight)
		       label: _(@"Host:")
		       alignment: NSRightTextAlignment];
  [self addSubview: label];

  label = [LabelWidget labelWidgetWithFrame: NSMakeRect(10,145,150,TextFieldHeight)
		       label: _(@"(Ex: mail.host.com)")
		       alignment: NSLeftTextAlignment];
  [label setFont: [NSFont systemFontOfSize: 10]];
  [self addSubview: label];

  sendSMTPHostField = [[NSTextField alloc] initWithFrame: NSMakeRect(75,165,200,TextFieldHeight)];
  [self addSubview: sendSMTPHostField];

  label = [LabelWidget labelWidgetWithFrame: NSMakeRect(275,165,45,TextFieldHeight)
		       label: _(@"Port:")
		       alignment: NSRightTextAlignment];
  [self addSubview: label];
  
  label = [LabelWidget labelWidgetWithFrame: NSMakeRect(300,145,75,TextFieldHeight)
		       label: _(@"(Usually, 25)")
		       alignment: NSLeftTextAlignment];
  [label setFont: [NSFont systemFontOfSize: 10]];
  [self addSubview: label];

  sendSMTPPortField = [[NSTextField alloc] initWithFrame: NSMakeRect(325,165,50,TextFieldHeight)];
  [self addSubview: sendSMTPPortField];


  sendAuthenticateUsingButton = [[NSButton alloc] initWithFrame: NSMakeRect(10,120,130,ButtonHeight)];
  [sendAuthenticateUsingButton setButtonType: NSSwitchButton];
  [sendAuthenticateUsingButton setBordered: NO];
  [sendAuthenticateUsingButton setTitle: _(@"Authenticate using")];
  [sendAuthenticateUsingButton setTarget: parent];
  [sendAuthenticateUsingButton setAction: @selector(sendAuthenticateUsingButtonClicked:)];
  [self addSubview: sendAuthenticateUsingButton];

  sendSupportedMechanismsPopUp = [[NSPopUpButton alloc] initWithFrame: NSMakeRect(140,120,80,ButtonHeight)];
  [self addSubview: sendSupportedMechanismsPopUp];

  sendSupportedMechanismsButton = [[NSButton alloc] initWithFrame: NSMakeRect(230,120,145,ButtonHeight)];
  [sendSupportedMechanismsButton setTitle: _(@"Supported mechanisms")];
  [sendSupportedMechanismsButton setTarget: parent];
  [sendSupportedMechanismsButton setAction: @selector(sendSupportedMechanismsButtonClicked:)];
  [self addSubview: sendSupportedMechanismsButton];

  label = [LabelWidget labelWidgetWithFrame: NSMakeRect(10,90,60,TextFieldHeight)
		       label: _(@"Username:")
		       alignment: NSLeftTextAlignment];
  [self addSubview: label];

  sendSMTPUsernameField = [[NSTextField alloc] initWithFrame: NSMakeRect(75,90,300,TextFieldHeight)];
  [self addSubview: sendSMTPUsernameField];
 
  // Remember password option
  sendRememberPassword = [[NSButton alloc] initWithFrame: NSMakeRect(10,60,200,ButtonHeight)];
  [sendRememberPassword setButtonType: NSSwitchButton];
  [sendRememberPassword setBordered: NO];
  [sendRememberPassword setTitle: _(@"Remember password")];
  [sendRememberPassword setTarget: parent];
  [sendRememberPassword setAction: @selector(sendRememberPasswordClicked:)];
  [self addSubview: sendRememberPassword];

  // Password
  label = [LabelWidget labelWidgetWithFrame: NSMakeRect(10,35,60,TextFieldHeight)
		       label: _(@"Password:")
		       alignment: NSLeftTextAlignment];
  [self addSubview: label];
  
  sendSMTPPasswordSecureField = [[NSSecureTextField alloc] initWithFrame: NSMakeRect(75,35,300,TextFieldHeight)];
  [self addSubview: sendSMTPPasswordSecureField];
 
  
  // Use SSL option
  sendUseSecureConnection = [[NSButton alloc] initWithFrame: NSMakeRect(10,5,250,ButtonHeight)];
  [sendUseSecureConnection setButtonType: NSSwitchButton];
  [sendUseSecureConnection setBordered: NO];
  [sendUseSecureConnection setTitle: _(@"Use secure connection (SSL)")];
  [sendUseSecureConnection setTarget: parent ];
  [sendUseSecureConnection setAction: @selector(sendUseSecureConnectionClicked:)];
  [self addSubview: sendUseSecureConnection];
}

@end
