/*
**  Constants.h
**
**  Copyright (c) 2003
** 
**  Author: Ludovic Marcotte <ludovic@Sophos.ca>   
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#ifndef _GNUMail_H_GNUMailConstants
#define _GNUMail_H_GNUMailConstants

#ifdef MACOSX
#define RETAIN(object)          [object retain]
#define RELEASE(object)         [object release]
#define AUTORELEASE(object)     [object autorelease]
#define TEST_RELEASE(object)    ({ if (object) [object release]; })
#define ASSIGN(object,value)    ({\
id __value = (id)(value); \
id __object = (id)(object); \
if (__value != __object) \
  { \
    if (__value != nil) \
      { \
        [__value retain]; \
      } \
    object = __value; \
    if (__object != nil) \
      { \
        [__object release]; \
      } \
  } \
})

#define DESTROY(object) ({ \
  if (object) \
    { \
      id __o = object; \
      object = nil; \
      [__o release]; \
    } \
})

#define NSLocalizedString(key, comment) \
  [[NSBundle mainBundle] localizedStringForKey:(key) value:@"" table:nil]

#define _(X) NSLocalizedString (X, @"")

#ifdef DEBUG
#define NSDebugLog(format, args...) \
  do { NSLog(format, ##args); } while(0)
#else
#define NSDebugLog(format, args...)
#endif

#endif


//
// Useful macros
//
#define IMAPSTORE_IS_DISCONNECTED(store) ({ \
  BOOL aBOOL; \
  \
  aBOOL = NO; \
  \
  if ( [(id<NSObject>)store isKindOfClass: [IMAPStore class]] && \
       ![[(IMAPStore *)store tcpConnection] isConnected] ) \
    { \
      aBOOL = YES; \
    } \
  \
  aBOOL; \
})


//
// Constants for the application
//
#define MANUALLY      0
#define AUTOMATICALLY 1

#define SHOW_ALL_HEADERS 1
#define HIDE_ALL_HEADERS 2

#define DELETE_MESSAGE   1
#define UNDELETE_MESSAGE 2

#define MARK_AS_READ   1
#define MARK_AS_UNREAD 2

#define SHOW_DELETED_MESSAGES 1
#define HIDE_DELETED_MESSAGES 2

#define SHOW_READ_MESSAGES 1
#define HIDE_READ_MESSAGES 2

#define THREAD_MESSAGES   1
#define UNTHREAD_MESSAGES 2

#define OTHER 0
#define POP3  1
#define IMAP  2
#define UNIX  3

#define TRANSPORT_MAILER 1
#define TRANSPORT_SMTP   2

#define SIGNATURE_BEGINNING 0
#define SIGNATURE_END       1
#define SIGNATURE_HIDDEN    2

#define MOVE_MESSAGES 1
#define COPY_MESSAGES 2

#define TYPE_TABLEVIEW   1
#define TYPE_OUTLINEVIEW 2

#define MODE_STANDARD 1
#define MODE_EXPERT   2

#define TYPE_PLAIN 1
#define TYPE_HTML  2

#define RETAIN_PERIOD 300
//
// Constants for the UI
//
#define TextFieldHeight    21
#define ButtonHeight       25
#define FilterTextFieldTag 1001


//
// Notifications used in GNUMail.app
//
#define SelectionOfMessageHasChanged @"SelectionOfMessageHasChanged"
#define AccountsHaveChanged          @"AccountsHaveChanged"
#define FiltersHaveChanged           @"FiltersHaveChanged"
#define ReplyToMessageWasSuccessful  @"ReplyToMessageWasSuccessful"
#define FontValuesHaveChanged        @"FontValuesHaveChanged"
#define TableColumnsHaveChanged      @"TableColumnsHaveChanged"


//
// Pasteboard data types
//
#define MessagePboardType @"MessagePboardType"
#define AddressPboardType @"AddressPboardType"


//
// Addressbook types
//
#define GNUMAIL_ADDRESSBOOK_TYPE 0
#define APPLE_ADDRESSBOOK_TYPE	 1

#endif // _GNUMail_H_GNUMailConstants
