/*
**  GetURLScriptCommand.m
**
**  Copyright (c) 2003
**
**  Author: Ujwal S. Sathyam
**
**  Project: GNUMail
**
**  Description: Implements Applescript support for GNUMail.
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include "GetURLScriptCommand.h"

#include "GNUMail.h"


//
//
//
@implementation GetURLScriptCommand

- (id) scriptError: (int) errorNumber 
       description: (NSString *) description
{
  [self setScriptErrorNumber: errorNumber];
  [self setScriptErrorString: description];
  return nil;
}


- (id)performDefaultImplementation
{
  NSString *command;
  NSString *parameter;
  
  command = [[self commandDescription] commandName];
  parameter = [self directParameter];
  
  if ([command isEqualToString: @"GetURL"] && [parameter length])
    {
      NSString *anAddress;
      NSRange aRange;
      
      // Search for "mailto" token
      aRange = [parameter rangeOfString: @"mailto" options: NSCaseInsensitiveSearch];
     
      if (aRange.length <= 0)
	{
	  return nil;
	}

      anAddress = [parameter substringFromIndex: (aRange.location + aRange.length)];
      
      // Serach for ":" token
      aRange = [anAddress rangeOfString: @":"];
      
      if (aRange.length <= 0)
	{
	  return nil;
	}
      
      anAddress = [anAddress substringFromIndex: (aRange.location + aRange.length)];
      
      // Open an mail composer window addressed to to "anAddress"
      if ([anAddress length] > 0)
	{
	  GNUMail *gnumail;
	  
	  gnumail = [NSApp delegate];
	  
	  [gnumail newMessageWithRecipient: anAddress];
	}
    }
  
  return (nil);
}

@end
