/*
**  MailboxManagerToolbar.m
**
**  Copyright (c) 2002, 2003
**
**  Author: Francis Lachapelle <francis@Sophos.ca>
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#include "MailboxManagerToolbar.h"

#include "Constants.h"
#include "ExtendedOutlineView.h"

@implementation MailboxManagerController (MailboxManagerToolbar)

//
// NSToolbar delegate methods
//
- (NSToolbarItem *) toolbar: (NSToolbar *) toolbar
      itemForItemIdentifier: (NSString *) itemIdentifier
  willBeInsertedIntoToolbar: (BOOL) flag
{
  NSToolbarItem *item = [[NSToolbarItem alloc] initWithItemIdentifier: itemIdentifier];
  
  if ([itemIdentifier isEqualToString: @"delete"])
    {
      [item setLabel: _(@"Delete")];
      [item setPaletteLabel: _(@"Delete Mailbox")];
      [item setImage: [NSImage imageNamed: @"delete_32.tiff"]];
      [item setTarget: self];
      [item setAction: @selector(delete:)];
    }
  else if ([itemIdentifier isEqualToString: @"create"])
    {
      [item setLabel: _(@"Create")];
      [item setPaletteLabel: _(@"Create Mailbox")];
      [item setImage: [NSImage imageNamed: @"mailbox_add_32.tiff"]];
      [item setTarget: self];
      [item setAction: @selector(create:)];
    }
  else if ([itemIdentifier isEqualToString: @"rename"])
    {
      [item setLabel: _(@"Rename")];
      [item setPaletteLabel: _(@"Rename Mailbox")];
      [item setImage: [NSImage imageNamed: @"mailbox_rename_32.tiff"]];
      [item setTarget: self];
      [item setAction: @selector(rename:)];
    }
  else if ([itemIdentifier isEqualToString: @"move"])
    {
      [item setLabel: _(@"Move")];
      [item setPaletteLabel: _(@"Move Messages")];
      [item setToolTip: _(@"Move selected messages to selected mailbox")];
      [item setTag: MOVE_MESSAGES];
      [item setImage: [NSImage imageNamed: @"mailbox_move_32.tiff"]];
      [item setTarget: self];
      [item setAction: @selector(transfer:)];
    }
  else if ([itemIdentifier isEqualToString: @"copy"])
    {
      [item setLabel: _(@"Copy")];
      [item setPaletteLabel: _(@"Copy Messages")];
      [item setToolTip: _(@"Copy selected messages to selected mailbox")];
      [item setTag: COPY_MESSAGES];
      [item setImage: [NSImage imageNamed: @"mailbox_copy_32.tiff"]];
      [item setTarget: self];
      [item setAction: @selector(transfer:)];
    }

  return [item autorelease];
}


- (NSArray *) toolbarAllowedItemIdentifiers: (NSToolbar*) toolbar
{
  return [NSArray arrayWithObjects: NSToolbarSeparatorItemIdentifier,
		  NSToolbarSpaceItemIdentifier,
		  NSToolbarFlexibleSpaceItemIdentifier,
		  NSToolbarCustomizeToolbarItemIdentifier, 
		  @"delete",
                  @"create",
		  @"rename",
		  @"move",
		  @"copy",
		  nil];
}


- (NSArray *) toolbarDefaultItemIdentifiers: (NSToolbar*) toolbar
{
  return [NSArray arrayWithObjects: @"delete",
		  @"create",
		  @"rename",
		  NSToolbarFlexibleSpaceItemIdentifier,
		  @"move",
		  @"copy",
		  nil];
}


//
// NSToolbarItemValidation protocol
//
- (BOOL) validateToolbarItem:(NSToolbarItem *)theItem
{
  int row, level;
  id item;
  

  row = [outlineView selectedRow];
  item = [outlineView itemAtRow: row];
  level = [outlineView levelForItem: item];
  
  if ( [theItem action] == @selector(delete:) ||
       [theItem action] == @selector(rename:) ||
       [theItem action] == @selector(transfer:) )
    {
      return ( [outlineView selectedRow] > 0 &&
	       [outlineView numberOfSelectedRows] == 1 &&
	       level >= 1 );
    }
  else if ( [theItem action] == @selector(create:) )
    {
      return ( [outlineView selectedRow] >= 0 &&
		[outlineView numberOfSelectedRows] == 1 &&
		level >= 0 );
    }

  return YES;
}

@end
